pub enum InsertMode {
Unrestricted,
DenyNewRows,
DenyNewColumns,
DenyNewRowsAndColumns,
}Expand description
Defines insert data behavior – where data may be inserted.
Variants
Unrestricted
Can add new rows or column
DenyNewRows
Cannot add new rows, but can add new columns
DenyNewColumns
Cannot add new columns, but can add new rows
DenyNewRowsAndColumns
No adding new rows or columns